@@ -23,7 +23,7 @@ Implementation Notes
 
 """
 
-__version__ = "2.28.0"
+__version__ = "2.28.1"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Display_Text.git"
 
 import displayio
@@ -53,7 +53,7 @@ class Label(LabelBase):
 
     :param font: A font class that has ``get_bounding_box`` and ``get_glyph``.
       Must include a capital M for measuring character size.
-    :type font: ~FontProtocol
+    :type font: ~fontio.FontProtocol
     :param str text: Text to display
     :param int|Tuple(int, int, int) color: Color of all text in HEX or RGB
     :param int|Tuple(int, int, int)|None background_color: Color of the background, use `None`
